"""Tests for the models of the ``multilingual_events`` app."""
from django.test import TestCase
from django.utils import timezone

from ..models import Event
from .factories import EventFactory, EventTitleFactory


class EventManagerTestCase(TestCase):
    """Tests for the ``EventManager`` class."""
    longMessage = True

    def test_get_visible(self):
        manager = Event.objects

        # the following two events should be visible
        # a visible event
        EventFactory()

        # a past event with future end date
        past = timezone.now() - timezone.timedelta(1)
        future = timezone.now() + timezone.timedelta(1)
        EventFactory(start_date=past, end_date=future)

        # the following two events should be invisible
        # an invisible event
        EventFactory(is_published=False)

        # a past event
        past = timezone.now() - timezone.timedelta(1)
        EventFactory(start_date=past)

        result = manager.get_visible()
        self.assertEqual(result.count(), 2)


class EventTestCase(TestCase):
    """Tests for the ``Event`` model class."""
    longMessage = True

    def test_model(self):
        instance = EventFactory()
        self.assertTrue(instance.pk, msg=(
            'Should be able to instantiate and save the model.'))


class EventTitleTestCase(TestCase):
    """Tests for the ``EventTitle`` model class."""
    longMessage = True

    def test_model(self):
        instance = EventTitleFactory()
        self.assertTrue(instance.pk, msg=(
            'Should be able to instantiate and save the model.'))



"""Views for the ``multilingual_events`` app."""
from django.views.generic import DetailView, TemplateView
from django.utils import timezone

from simple_translation.middleware import filter_queryset_language

from .models import Event


class EventListView(TemplateView):
    """A view that lists all upcoming events for the current language."""
    template_name = 'multilingual_events/event_list.html'

    def get_context_data(self, **kwargs):
        ctx = super(EventListView, self).get_context_data(**kwargs)

        yesterday = timezone.now().date() - timezone.timedelta(1)

        qs = Event.objects.filter(is_published=True)
        qs = qs.filter(start_date__gte=yesterday)
        upcoming = filter_queryset_language(self.request, qs)

        qs = Event.objects.filter(is_published=True)
        qs = qs.filter(start_date__lt=yesterday)
        archived = filter_queryset_language(self.request, qs)
        ctx.update({
            'upcoming_events': upcoming,
            'archived_events': archived,
        })
        return ctx


class EventDetailView(DetailView):
    """A view that displays detailed information about an event."""
    model = Event
